## AI 프롬프트 활용 3-6
#### 마이크로파이썬 변수 이름 짓는 법
```
마이크로파이썬으로 코딩할 때 변수 이름을 잘 짓는 방법을 알려줘.   
```
## AI가 만든 결과
마이크로파이썬(MicroPython)은 임베디드 환경 등 제약된 자원 위에서 동작하도록 최적화된 파이썬 구현체이지만, 변수 이름을 짓는 방식은 일반적인 파이썬 코드 작성 원칙과 크게 다르지 않습니다. 다만, 메모리가 제한적인 환경을 고려해야 하므로 ‘너무 긴 이름을 피하면서도, 의미가 명확하도록’ 균형을 잡는 것이 좋습니다. 아래는 변수 이름을 효율적이면서 가독성 좋게 짓는 방법에 대한 가이드입니다.

---

## 1. 의미가 담긴 이름 사용하기
- **설명 가능한 단어 사용**  
  `temp_value`, `led_status`와 같이, 변수 자체만으로도 어떤 역할이나 의미를 짐작할 수 있어야 합니다.  
- **애매한 축약어 지양**  
  무턱대고 `val`, `dt`, `tmp` 같은 축약어만 쓰면, 나중에 해당 변수의 의도가 불명확해질 수 있습니다.  
- **짧더라도 컨텍스트가 드러나도록**  
  너무 긴 이름은 메모리나 코드 공간에 부담이 될 수 있으니, `temperature` 대신 `temp`, `microphone` 대신 `mic` 등과 같이 대표적인 약어(축약어)를 사용할 수 있습니다. 단, 축약 전에 팀 내에서 통일된 기준이 있는지 확인하세요.

---

## 2. 파이썬 스타일 가이드(PEP 8) 따르기
- **snake_case**  
  파이썬에서 권장되는 변수 이름 표기법은 소문자와 밑줄(_)을 사용하는 스네이크 케이스(snake_case)입니다. 예) `led_pin`, `adc_value`  
- **의미 단위별 구분**  
  이름 안에 다른 의미가 들어가야 할 때는 `_`를 사용해 구분합니다. 예) `sensor_data_buffer`  
- **일관성 유지**  
  한 모듈 또는 프로젝트 내에서는 가급적 동일한 표기법을 유지해야 코드를 이해하기 쉽고, 유지보수가 편합니다.

---

## 3. 메모리·성능 제약 고려하기
- **너무 긴 변수명 자제**  
  MicroPython 환경은 RAM이 몇 KB ~ 수백 KB 정도로 제한적인 경우가 많습니다. 따라서 불필요하게 긴 변수 이름을 무작정 사용하는 것은 피하는 것이 좋습니다.  
- **짧고 규칙적인 네이밍**  
  예를 들어, 센서가 여러 개 있다면 `sensor1_temp`, `sensor2_temp`처럼 짧은 고정 포맷을 사용합니다.  
- **주석 활용**  
  이름만으로 충분히 의미를 표현하기 어렵다면, 주석을 통해 부가 설명을 보충하세요. 짧은 이름을 사용하되, 주석으로 의미를 명확히 할 수 있습니다.

---

## 4. 맥락에 따라 스코프 조정하기
- **함수 내 임시 변수**  
  짧은 루프 변수(`i`, `j`)나 임시 변수라면 크게 문제되지 않습니다. 다만, 함수를 분할해 코드의 맥락이 명확해지도록 작성하면, 짧은 변수 이름을 쓰더라도 혼동이 줄어듭니다.  
- **전역 변수 피하기**  
  전역 변수를 자주 사용하면 코드가 복잡해지고, 충돌 위험이 늘어납니다. 필요하다면 모듈 범위 등으로 최소화하고, 이름도 다른 변수와 충돌하지 않도록 명확히 정합니다.

---

## 5. 팀 내 합의 및 코드 리뷰
- **공통 규칙 정하기**  
  팀 내에서 사용하기로 합의된 줄임말이나 네이밍 스타일이 있다면, 그것을 공유하고 문서화하세요. 예: `sensor`는 `sns`로 축약, `configuration`은 `cfg`로 축약 등.  
- **코드 리뷰를 통해 개선**  
  변수 이름의 가독성은 코드 리뷰를 거치면서 자연스럽게 개선됩니다. 너무 길거나 모호한 이름이 있으면 팀원들이 피드백을 주고받으며 다듬습니다.

---

### 정리
MicroPython에서 변수 이름을 잘 짓는 핵심은 **의미가 분명하고 간결한 네이밍**을 통해 읽기 쉽고 유지보수하기 쉬운 코드를 만드는 것입니다. 파이썬의 스타일 가이드(PEP 8)를 기본으로 삼되, 메모리와 성능 제약을 고려해 과도하게 긴 이름을 피하고, 필요한 경우 주석이나 팀 내 합의된 축약어를 사용하면 좋습니다.